from setuptools import setup

setup(
    name='terra_ai',
    version='2.4',
    packages=['terra_ai'],
    url='',
    license='',
    author='AI University',
    author_email='nejronki@gmail.com'    
)
